# latest-earthquake-report-indonesia
This package inform the latest earthquake in Indonesia from BMKG | Meteorological, Climatological, and Geophysical Agency.

## How it work
This package informs earthquake that just occurred in Indonesia, sourced from BMKG.

## How to use
```
import gempaterkini

if __name__ == '__main__':
    print("Aplikasi Utama")
    result = gempaterkini.ekstraksi_data()
    gempaterkini.tampilkan_data(result)
```

# Author
Panji Perdana

